# NeuralActivityCubic
Indoc Research`s approach into [NeuralActivityCubic](https://github.com/jpits30/NeuronActivityTool), published by [Prada et al. 2018 (Plos Comp. Biol.)](https://doi.org/10.1371/journal.pcbi.1006054). The code you can find in this repository was the outcome of our Teams 6-hour Hackathon during our Christmas Retreat. We will provide more information on this project soon on our [website](https://www.indocresearch.eu/news).

# How to use
```python
import neuralactivitycubic as na3

na3.open_gui()
```

If you want to test it without any local installation, please click [>>here<<](https://mybinder.org/v2/gh/Indoc-Research/NeuralActivityCubic/HEAD?urlpath=lab/tree/NeuralActivityCubic_demo.ipynb) to launch the Jupyter Notebook directly in your Webbrowser. This will run a container hosted completely for free on [MyBinder](https://mybinder.org/).
